SCOPES = ['https://www.googleapis.com/auth/spreadsheets']
LIGUEID = 817430786629173258
SHEETID = "1lJTFm6xMdUYA22tadIdAMZO5pYOH3Sc1OEVZsfeB_h4"
STAT = "Split_2!A4:S53"
BOTSPAM = 833778930858852413
BOTRETOURGENERAL = 834892751363375155
MAINEVENT1 = {
	"ListeMatch": "S3_ME!V4:Z170",
	"ListeScore": "S3_ME!W4:X170",
	"ListeInscrit": "S3_ME!P4:U51",
	"ListedAttente": "S3_ME!P52:U170",
	"bot-channel": 848664401069867088,
	"Categorie": 702453004179079248,
	"NomRole": "MainEvent"
}
SIDEEVENT1 = {
	"ListeMatch": "S3_SE!V4:Z110",
	"ListeScore": "S3_SE!W4:X110",
	"ListeInscrit": "S3_SE!P4:U27",
	"ListedAttente": "S3_SE!P28:U110",
	"bot-channel": 848664537355386890,
	"Categorie": 805195339803131914,
	"NomRole": "SideEvent"
}
FUNEVENT1 = {
	"ListeMatch": "S3_FE!V4:Z66",
	"ListeScore": "S3_FE!W4:X66",
	"ListeInscrit": "S3_FE!P4:U23",
	"ListedAttente": "S3_FE!P24:U66",
	"bot-channel": 848664935332446228,
	"Categorie": 810987751117815838,
	"NomRole": "FunEvent"
}
MAINEVENT2 = {
	"ListeMatch": "S4_ME!V4:Z170",
	"ListeScore": "S4_ME!W4:X170",
	"ListeInscrit": "S4_ME!P4:U51",
	"ListedAttente": "S4_ME!P52:U170",
	"bot-channel": 848664401069867088,
	"Categorie": 702453004179079248,
	"NomRole": "MainEvent"
}
SIDEEVENT2 = {
	"ListeMatch": "S4_SE!V4:Z110",
	"ListeScore": "S4_SE!W4:X110",
	"ListeInscrit": "S4_SE!P4:U27",
	"ListedAttente": "S4_SE!P28:U110",
	"bot-channel": 848664537355386890,
	"Categorie": 805195339803131914,
	"NomRole": "SideEvent"
}
FUNEVENT2 = {
	"ListeMatch": "S4_FE!V4:Z66",
	"ListeScore": "S4_FE!W4:X66",
	"ListeInscrit": "S4_FE!P4:U23",
	"ListedAttente": "S4_FE!P24:U66",
	"bot-channel": 848664935332446228,
	"Categorie": 810987751117815838,
	"NomRole": "FunEvent"
}
MAINEVENT = MAINEVENT2
SIDEEVENT = SIDEEVENT2
FUNEVENT = FUNEVENT2
